# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

appAuth: Optional[str]
"""
The GitHub App credentials used to connect to GitHub. Conflicts with `token`. Anonymous mode is enabled if both `token`
and `app_auth` are not set.
"""

baseUrl: str
"""
The GitHub Base API URL
"""

insecure: Optional[bool]
"""
Enable `insecure` mode for testing purposes
"""

maxRetries: Optional[int]
"""
Number of times to retry a request after receiving an error status codeDefaults to 3
"""

organization: Optional[str]
"""
The GitHub organization name to manage. Use this field instead of `owner` when managing organization accounts.
"""

owner: Optional[str]
"""
The GitHub owner name to manage. Use this field instead of `organization` when managing individual accounts.
"""

parallelRequests: Optional[bool]
"""
Allow the provider to make parallel API calls to GitHub. You may want to set it to true when you have a private Github
Enterprise without strict rate limits. Although, it is not possible to enable this setting on github.com because we
enforce the respect of github.com's best practices to avoid hitting abuse rate limitsDefaults to false if not set
"""

readDelayMs: Optional[int]
"""
Amount of time in milliseconds to sleep in between non-write requests to GitHub API. Defaults to 0ms if not set.
"""

retryDelayMs: Optional[int]
"""
Amount of time in milliseconds to sleep in between requests to GitHub API after an error response. Defaults to 1000ms or
1s if not set, the max_retries must be set to greater than zero.
"""

retryableErrors: Optional[str]
"""
Allow the provider to retry after receiving an error status code, the max_retries should be set for this to workDefaults
to [500, 502, 503, 504]
"""

token: Optional[str]
"""
The OAuth token used to connect to GitHub. Anonymous mode is enabled if both `token` and `app_auth` are not set.
"""

writeDelayMs: Optional[int]
"""
Amount of time in milliseconds to sleep in between writes to GitHub API. Defaults to 1000ms or 1s if not set.
"""

